@@ -3,9 +3,6 @@ package AtteanX::Query::AccessPlan::SingleQuadBGP;
 use strict;
 use warnings;
 
-our $AUTHORITY = 'cpan:KJETILK';
-our $VERSION   = '0.011_01';
-
 use Moo::Role;
 use AtteanX::Plan::SPARQLBGP;
 
